Struct MiningQueued
pub struct MiningQueued {
pub position: BlockPos,
pub direction: Direction,
pub force: bool,
}Expand description
Present on entities when they’re going to start mining a block next tick.
Fields
position: BlockPosdirection: Directionforce: boolWhether we should mine the block regardless of whether it’s reachable.